==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/7c/7c725584933b46175e76ee0c54e26138.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/IntegrationsBundle/Mapping/MappedFieldInfoInterface.php */
class __TwigTemplate_5ea5803f455ff5786a478f0897027587 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\IntegrationsBundle\\Mapping;

interface MappedFieldInfoInterface
{
    public function getName(): string;

    public function getLabel(): string;

    public function showAsRequired(): bool;

    public function hasTooltip(): bool;

    public function getTooltip(): string;

    public function isBidirectionalSyncEnabled(): bool;

    public function isToIntegrationSyncEnabled(): bool;

    public function isToMauticSyncEnabled(): bool;
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/IntegrationsBundle/Mapping/MappedFieldInfoInterface.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/IntegrationsBundle/Mapping/MappedFieldInfoInterface.php", "/var/www/mautic-ktn/app/bundles/IntegrationsBundle/Mapping/MappedFieldInfoInterface.php");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/7c/7c725584933b46175e76ee0c54e26138.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/IntegrationsBundle/Mapping/MappedFieldInfoInterface.php */
class __TwigTemplate_5ea5803f455ff5786a478f0897027587 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\IntegrationsBundle\\Mapping;

interface MappedFieldInfoInterface
{
    public function getName(): string;

    public function getLabel(): string;

    public function showAsRequired(): bool;

    public function hasTooltip(): bool;

    public function getTooltip(): string;

    public function isBidirectionalSyncEnabled(): bool;

    public function isToIntegrationSyncEnabled(): bool;

    public function isToMauticSyncEnabled(): bool;
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/IntegrationsBundle/Mapping/MappedFieldInfoInterface.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/IntegrationsBundle/Mapping/MappedFieldInfoInterface.php", "/var/www/html/mauticGIT-Test/app/bundles/IntegrationsBundle/Mapping/MappedFieldInfoInterface.php");
    }
}
